scanner_group

package
v0.0.0-...-5a21cb2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateScannerGroup

func CreateScannerGroup(apiKey, name, groupType, description string) error

CreateScannerGroup sends a request to create a new scanner-group group in Tenable.io.

func DeleteScannerGroup

func DeleteScannerGroup(apiKey, groupID string) error

DeleteScannerGroup sends a request to delete a scanner-group group by its ID.

func UpdateScannerGroup

func UpdateScannerGroup(apiKey, groupID, newName string) error

UpdateScannerGroup updates the specified scanner-group group's name.

Types

type ScannerGroupCreateRequest

type ScannerGroupCreateRequest struct {
	Name        string `json:"name"`
	Type        string `json:"type"`
	Description string `json:"description,omitempty"`
}

ScannerGroupCreateRequest represents the request payload for creating a scanner-group group.

type ScannerGroupUpdateRequest

type ScannerGroupUpdateRequest struct {
	Name string `json:"name"`
}

ScannerGroupUpdateRequest represents the JSON payload for updating a scanner-group group.

Jump to