Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateScannerGroup ¶
CreateScannerGroup sends a request to create a new scanner-group group in Tenable.io.
func DeleteScannerGroup ¶
DeleteScannerGroup sends a request to delete a scanner-group group by its ID.
func UpdateScannerGroup ¶
UpdateScannerGroup updates the specified scanner-group group's name.
Types ¶
type ScannerGroupCreateRequest ¶
type ScannerGroupCreateRequest struct {
Name string `json:"name"`
Type string `json:"type"`
Description string `json:"description,omitempty"`
}
ScannerGroupCreateRequest represents the request payload for creating a scanner-group group.
type ScannerGroupUpdateRequest ¶
type ScannerGroupUpdateRequest struct {
Name string `json:"name"`
}
ScannerGroupUpdateRequest represents the JSON payload for updating a scanner-group group.
Click to show internal directories.
Click to hide internal directories.